@@ -156,7 +156,7 @@ def upload2(filepath, conf, file_id):
                 break
             # todo 应该校验crc32，但是 Fdfs 是自定义的 hash 规则。还没实现。有空再说
             ret = cli.append_by_buffer(buffer, file_id)
-            print(ret)
+            # print(ret)
 
 
 @main.command()
